@@ -1,7 +1,8 @@
 #!/usr/bin/env ruby
+# encoding: UTF-8
 
-require 'test/unit'
-require 'ruby-prof'
+require File.expand_path('../test_helper', __FILE__)
+require 'stringio'
 require 'timeout'
 
 # --  Test for bug [#5657]
@@ -24,14 +25,15 @@ class A
   end
 end
 
-class SingletonTest < Test::Unit::TestCase
+class SingletonTest < TestCase
   def test_singleton
-    result = RubyProf.profile do
+    result = RubyProf::Profile.profile do
       a = A.new
       a << :first_thing
       assert_equal(1, a.as.size)
     end
     printer = RubyProf::FlatPrinter.new(result)
-    printer.print(STDOUT)
+    output = ENV['SHOW_RUBY_PROF_PRINTER_OUTPUT'] == "1" ? STDOUT : StringIO.new
+    printer.print(output)
   end
-end
\ No newline at end of file
+end
